from setuptools import setup, find_packages

setup(
    name='vibe-pentesterlab',
    version='1.0.0',
    author='Prajeesh KC',
    author_email='prajeesh@example.com',
    description='A fully automated bug bounty recon and vulnerability scanner with GUI.',
    long_description=open("README.md").read(),
    long_description_content_type='text/markdown',
    url='https://github.com/kcprajeesh/Vibe-pentesterlab',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'aiohttp',
        'requests',
        'streamlit'
    ],
    entry_points={
        'console_scripts': [
            'vibe = vibe.__main__:main'
        ]
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.10',
)